
# Slot: source_file_size


size in bytes of the source of the schema

URI: [meta:source_file_size](https://w3id.org/biolink/biolinkml/meta/source_file_size)

## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [Integer](Integer.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
